@@ -119,9 +119,7 @@ typedef union SWFMovieBlockType_u SWFMovieBlockType;
 #if __GNUC__ > 3 ||  \
 	(__GNUC__ == 3 && (__GNUC_MINOR__ > 3 || \
                  (__GNUC_MINOR__ == 3 && __GNUC_PATCHLEVEL__ > 0)))
-/* #define __to_movie_block(x) (union SWFMovieBlockType_u)x */
-/* Commented by Yixuan Qiu */
-#define __to_movie_block(x) (union SWFMovieBlockType_u) { x }
+#define __to_movie_block(x) (union SWFMovieBlockType_u)x
 #else
 #define __to_movie_block(x) (union SWFMovieBlockType_u) { x }
 #endif
@@ -1042,7 +1040,7 @@ SWFDisplayItem SWFMovie_add_internal(SWFMovie movie, SWFMovieBlockType ublock);
 #define SWFMovie_add(__movie, __block) \
 	SWFMovie_add_internal((__movie), __to_movie_block((__block)))
 #else
-static inline SWFDisplayItem SWFMovie_add(SWFMovie movie, SWFBlock block)
+static SWFDisplayItem SWFMovie_add(SWFMovie movie, SWFBlock block)
 {
 	SWFMovieBlockType ublock;
 	ublock.block = block;
@@ -1055,7 +1053,7 @@ int SWFMovie_replace_internal(SWFMovie movie, SWFDisplayItem item, SWFMovieBlock
 #define SWFMovie_replace(__movie, __item, __block) \
 	SWFMovie_replace_internal((__movie), (__item), __to_movie_block((__block)))
 #else
-static inline int SWFMovie_replace(SWFMovie movie, SWFDisplayItem item, SWFBlock block)
+static int SWFMovie_replace(SWFMovie movie, SWFDisplayItem item, SWFBlock block)
 {
 	SWFMovieBlockType ublock;
 	ublock.block = block;
